@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2011 Andrew Ziem
+## Copyright (C) 2012 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -29,9 +29,9 @@ from Options import options
 import FileUtilities
 
 
-def __get_chrome_history(path):
+def __get_chrome_history(path, fn = 'History'):
     """Get Google Chrome or Chromium history version.  'path' is name of any file in same directory"""
-    path_history = os.path.join(os.path.dirname(path), 'History')
+    path_history = os.path.join(os.path.dirname(path), fn)
     ver = get_sqlite_int(path_history, 'select value from meta where key="version"')[0]
     assert(ver > 1)
     return ver
@@ -144,11 +144,34 @@ def delete_chrome_keywords(path):
     """Delete keywords table in Chromium/Google Chrome 'Web Data' database"""
     cols = ('short_name', 'keyword', 'favicon_url', 'originating_url', 'suggest_url')
     where = "where not date_created = 0"
-    cmds = __shred_sqlite_char_columns('keywords', cols, where)
+    cmds  = __shred_sqlite_char_columns('keywords', cols, where)
     cmds += "update keywords set usage_count = 0;"
+    ver = __get_chrome_history(path, 'Web Data')
+    if ver >= 43:
+        # keywords_backup table first seen in Google Chrome 17 / Chromium 17 which is Web Data version 43
+        cmds += __shred_sqlite_char_columns('keywords_backup', cols, where)
+        cmds += "update keywords_backup set usage_count = 0;"
+
     FileUtilities.execute_sqlite3(path, cmds)
 
 
+def delete_libreoffice_history(path):
+    """Erase LibreOffice's MRU in registrymodifications.xcu"""
+    import xml.dom.minidom
+    dom1 = xml.dom.minidom.parse(path)
+    modified = False
+    for node in dom1.getElementsByTagName("item"):
+        if not node.hasAttribute("oor:path"):
+            continue
+        if not node.getAttribute("oor:path").startswith('/org.openoffice.Office.Histories/Histories/'):
+            continue
+        node.parentNode.removeChild(node)
+        node.unlink()
+        modified = True
+    if modified:
+        dom1.writexml(open(path, "w"))
+
+
 def delete_mozilla_url_history(path):
     """Delete URL history in Mozilla places.sqlite (Firefox 3 and family)"""
 
