@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 ## BleachBit
-## Copyright (C) 2011 Andrew Ziem
+## Copyright (C) 2012 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -26,6 +26,7 @@ Test case for module FileUtilities
 
 
 import locale
+import platform
 import subprocess
 import sys
 import tempfile
@@ -257,6 +258,68 @@ class FileUtilitiesTestCase(unittest.TestCase):
             delete(filename, shred)
             self.assert_(not os.path.exists(filename))
 
+        def symlink_helper(link_fn):
+
+            if 'nt' == os.name:
+                from win32com.shell import shell
+                if not shell.IsUserAnAdmin():
+                    print 'WARNING: skipping symlink test because of insufficient privileges'
+                    return
+
+            # make regular file
+            (fd, srcname) = tempfile.mkstemp('bbregular')
+            os.close(fd)
+
+            # make symlink
+            self.assert_(os.path.exists(srcname))
+            linkname = tempfile.mktemp('bblink')
+            self.assert_(not os.path.exists(linkname))
+            link_fn(srcname, linkname)
+            self.assert_(os.path.exists(linkname))
+            self.assert_(os.path.lexists(linkname))
+
+            # delete symlink
+            delete(linkname, shred)
+            self.assert_(os.path.exists(srcname))
+            self.assert_(not os.path.lexists(linkname))
+
+            # delete regular file
+            delete(srcname, shred)
+            self.assert_(not os.path.exists(srcname))
+
+            ###
+            ### test broken symlink
+            ###
+            (fd, srcname) = tempfile.mkstemp('bbregular')
+            os.close(fd)
+            self.assert_(os.path.lexists(srcname))
+            link_fn(srcname, linkname)
+            self.assert_(os.path.lexists(linkname))
+            self.assert_(os.path.exists(linkname))
+
+            # delete regular file first
+            delete(srcname, shred)
+            self.assert_(not os.path.exists(srcname))
+
+            # clean up
+            delete(linkname, shred)
+            self.assert_(not os.path.exists(linkname))
+            self.assert_(not os.path.lexists(linkname))
+
+        if 'nt' == os.name and platform.uname()[3][0:3] > '5.1':
+            # Windows XP = 5.1
+            # test symlinks
+            import ctypes
+            kern = ctypes.windll.LoadLibrary("kernel32.dll")
+            def win_symlink(src, linkname):
+                rc = kern.CreateSymbolicLinkA(linkname, src, 0)
+                if rc == 0:
+                    print 'CreateSymbolicLinkA(%s, %s)' % (linkname, src)
+                    print 'CreateSymolicLinkA() failed, error = %s' % ctypes.FormatError()
+                    self.assertNotEqual(rc, 0)
+            symlink_helper(win_symlink)
+
+        # below this point, only posix
         if 'nt' == os.name:
             return
 
@@ -268,27 +331,7 @@ class FileUtilitiesTestCase(unittest.TestCase):
         self.assert_(not os.path.exists(filename))
 
         # test symlink
-        (fd, filename) = tempfile.mkstemp()
-        os.close(fd)
-        self.assert_(os.path.exists(filename))
-        linkname = '/tmp/bleachbitsymlinktest'
-        if os.path.lexists(linkname):
-            delete(linkname, shred)
-        self.assert_(not os.path.lexists(linkname))
-        os.symlink(filename, linkname)
-        self.assert_(os.path.lexists(linkname))
-        delete(linkname, shred)
-        self.assert_(os.path.exists(filename))
-        self.assert_(not os.path.lexists(linkname))
-        delete(filename, shred)
-        self.assert_(not os.path.exists(filename))
-
-        # test broken symlink
-        os.symlink(filename, linkname)
-        self.assert_(os.path.lexists(linkname))
-        self.assert_(not os.path.exists(linkname))
-        delete(linkname, shred)
-        self.assert_(not os.path.exists(linkname))
+        symlink_helper(os.symlink)
 
         # test fifo
         args = ["mkfifo", filename]
@@ -373,6 +416,8 @@ class FileUtilitiesTestCase(unittest.TestCase):
 
         # create a symlink
         linkname = '/tmp/bleachbitsymlinktest'
+        if os.path.lexists(linkname):
+            delete(linkname)
         os.symlink(filename, linkname)
         self.assert_(getsize(linkname) < 8192, "Symlink size is %d" % getsize(filename))
         delete(filename)
