@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 ## BleachBit
-## Copyright (C) 2011 Andrew Ziem
+## Copyright (C) 2012 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -27,6 +27,7 @@ Test case for module Windows
 
 
 import sys
+import tempfile
 import unittest
 
 import common
@@ -46,11 +47,11 @@ class WindowsTestCase(unittest.TestCase):
 
     def test_delete_locked_file(self):
         """Unit test for delete_locked_file"""
-        fn = "c:\\bleachbit_deleteme_later"
-        f = open(fn, "w")
-        f.close()
+        (fd, pathname) = tempfile.mkstemp('bbregular')
+        os.close(fd)
+        self.assert_(os.path.exists(pathname))
         try:
-            delete_locked_file(fn)
+            delete_locked_file(pathname)
         except pywintypes.error, e:
             if 5 == e.winerror and not shell.IsUserAnAdmin():
                 pass
@@ -127,6 +128,13 @@ class WindowsTestCase(unittest.TestCase):
         self.assert_(not detect_registry_key('HKCU\\Software\\DoesNotExist'))
 
 
+    def test_get_autostart_path(self):
+        """Unit test for get_autostart_path"""
+        pathname = get_autostart_path()
+        dirname = os.path.dirname(pathname)
+        self.assert_(os.path.exists(dirname), 'startup directory does not exist: %s' % dirname)
+
+
     def test_get_fixed_drives(self):
         """Unit test for get_fixed_drives"""
         drives = []
@@ -139,10 +147,9 @@ class WindowsTestCase(unittest.TestCase):
     def test_is_process_running(self):
         tests = ((True, 'explorer.exe'), \
             (True, 'ExPlOrEr.exe'), \
-            (True, 'svchost.exe'), \
             (False, 'doesnotexist.exe'))
         for test in tests:
-            self.assertEqual(test[0], is_process_running(test[1]))
+            self.assertEqual(test[0], is_process_running(test[1]), 'is_process_running(%s) != %s' % (test[1], test[0]))
             self.assertEqual(test[0], is_process_running_win32(test[1]))
             self.assertEqual(test[0], is_process_running_wmic(test[1]))
 
@@ -165,7 +172,8 @@ class WindowsTestCase(unittest.TestCase):
     def test_split_registry_key(self):
         """Unit test for split_registry_key"""
         tests = ( ('HKCU\\Software', _winreg.HKEY_CURRENT_USER, 'Software'),
-            ('HKLM\\SOFTWARE', _winreg.HKEY_LOCAL_MACHINE, 'SOFTWARE') )
+            ('HKLM\\SOFTWARE', _winreg.HKEY_LOCAL_MACHINE, 'SOFTWARE'),
+            ('HKU\\.DEFAULT', _winreg.HKEY_USERS, '.DEFAULT'))
         for (input_key, expected_hive, expected_key) in tests:
             (hive, key) = split_registry_key(input_key)
             self.assertEqual(expected_hive, hive)
